@@ -24,7 +24,15 @@ from livestyled.models.location import Location
 from livestyled.models.magic_field import MagicField
 from livestyled.models.news import News
 from livestyled.models.order import Order, OrderItem
-from livestyled.models.payment import MerchantAccount, PaymentCustomer, PaymentGateway, PaymentIntent, PaymentSource
+from livestyled.models.payment import (
+    MerchantAccount,
+    MerchantAccountFulfilmentPoint,
+    MerchantAccountFulfilmentPointPspToken,
+    PaymentCustomer,
+    PaymentGateway,
+    PaymentIntent,
+    PaymentSource
+)
 from livestyled.models.product import (
     Product,
     ProductCategory,
@@ -39,6 +47,7 @@ from livestyled.models.push_consent import PushConsent
 from livestyled.models.reality import Reality, RealityType
 from livestyled.models.season import Season
 from livestyled.models.sport_venue import SportVenue
+from livestyled.models.storage import Export
 from livestyled.models.team import Team
 from livestyled.models.ticket import Ticket
 from livestyled.models.ticket_auth import TicketAuth
@@ -62,6 +71,7 @@ __all__ = [
     DeviceReality,
     DeviceToken,
     Event,
+    Export,
     Fixture,
     FulfilmentPoint,
     FulfilmentPointCategory,
@@ -72,6 +82,8 @@ __all__ = [
     Location,
     MagicField,
     MerchantAccount,
+    MerchantAccountFulfilmentPoint,
+    MerchantAccountFulfilmentPointPspToken,
     News,
     Order,
     OrderItem,
