@@ -18,12 +18,14 @@ from livestyled.models import (
     DeviceReality,
     DeviceToken,
     Event,
+    Export,
     Fixture,
     FulfilmentPoint,
     LeagueTable,
     LeagueTableGroup,
     Location,
     MagicField,
+    MerchantAccountFulfilmentPointPspToken,
     News,
     Order,
     PaymentIntent,
@@ -62,12 +64,15 @@ from livestyled.schemas import (
     DeviceSchema,
     DeviceTokenSchema,
     EventSchema,
+    ExportSchema,
     FixtureSchema,
     FulfilmentPointSchema,
     LeagueTableGroupSchema,
     LeagueTableSchema,
     LocationSchema,
     MagicFieldSchema,
+    MerchantAccountFulfilmentPointPspTokenSchema,
+    MerchantAccountFulfilmentPointSchema,
     MerchantAccountSchema,
     NewsSchema,
     OrderSchema,
@@ -1324,11 +1329,12 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
             return self._create_resource(AudienceDeviceSchema, audience_device)
         except HTTPError as http_error:
             if http_error.response.status_code == 500:
-                if http_error.response.json() == {
+                res_json = http_error.response.json()
+                if res_json == {
                     'code': 500,
                     'type': 'ValidationException',
                     'message': 'audience: Audience and Device combination already exists'
-                }:
+                } or ('type' in res_json and res_json['type'] == 'UniqueConstraintViolationException'):
                     return audience_device
             raise
 
@@ -1406,17 +1412,43 @@ class LiveStyledResourceClient(LiveStyledAPIClient):
         return self._replace_resource(PaymentIntentSchema, payment_intent.id, payment_intent)
 
     def get_payment_customer(self, id: int or str) -> Generator[Dict, None, None]:
-        return self._get_resource(
-            id,
-            PaymentCustomerSchema,
-        )
+        return self._get_resource(id, PaymentCustomerSchema)
 
     def get_payment_customers(self, filters: dict or None) -> Generator[Dict, None, None]:
         return self._get_resource_list(PaymentCustomerSchema, filters=filters)
 
+    def get_merchant_account_fulfilment_point(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, MerchantAccountFulfilmentPointSchema)
+
+    def get_merchant_account_fulfilment_points(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(MerchantAccountFulfilmentPointSchema, filters=filters)
+
+    def get_merchant_account_fulfilment_point_psp_token(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, MerchantAccountFulfilmentPointPspTokenSchema)
+
+    def get_merchant_account_fulfilment_point_psp_tokens(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(MerchantAccountFulfilmentPointPspTokenSchema, filters=filters)
+
+    def create_merchant_account_fulfilment_point_psp_token(
+        self,
+        merchant_account_fulfilment_point_psp_token: MerchantAccountFulfilmentPointPspToken
+    ) -> MerchantAccountFulfilmentPointPspToken:
+        return self._create_resource(MerchantAccountFulfilmentPointPspTokenSchema, merchant_account_fulfilment_point_psp_token)
+
     # ---- CURRENCIES
 
     def get_currencies(
             self,
     ) -> Generator[Currency, None, None]:
         return self._get_resource_list(CurrencySchema)
+
+    # ---- Exports
+
+    def get_export(self, id: int or str) -> Generator[Dict, None, None]:
+        return self._get_resource(id, ExportSchema)
+
+    def get_exports(self, filters: dict or None) -> Generator[Dict, None, None]:
+        return self._get_resource_list(ExportSchema, filters=filters)
+
+    def update_export(self, export: Export, attributes: Dict) -> Export:
+        return self._update_resource(ExportSchema, export.id, attributes)
